pub struct JsonbObject { /* private fields */ }Expand description
A JSON object with keys sorted for efficient lookup.
Implementations
Sourceimpl JsonbObject
impl JsonbObject
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a JsonbObject with pre-allocated capacity.
Sourcepub fn get(&self, key: &str) -> Option<&JsonbValue>
pub fn get(&self, key: &str) -> Option<&JsonbValue>
Gets a value by key using binary search. O(log n)
Sourcepub fn get_mut(&mut self, key: &str) -> Option<&mut JsonbValue>
pub fn get_mut(&mut self, key: &str) -> Option<&mut JsonbValue>
Gets a mutable value by key using binary search. O(log n)
Sourcepub fn insert(&mut self, key: String, value: JsonbValue)
pub fn insert(&mut self, key: String, value: JsonbValue)
Inserts a key-value pair, maintaining sorted order.
Sourcepub fn remove(&mut self, key: &str) -> Option<JsonbValue>
pub fn remove(&mut self, key: &str) -> Option<JsonbValue>
Removes a key and returns its value if present.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if the object contains the given key.
Sourcepub fn values(&self) -> impl Iterator<Item = &JsonbValue>
pub fn values(&self) -> impl Iterator<Item = &JsonbValue>
Returns an iterator over the values.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, &JsonbValue)>
pub fn iter(&self) -> impl Iterator<Item = (&str, &JsonbValue)>
Returns an iterator over key-value pairs.
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = (&str, &mut JsonbValue)>
pub fn iter_mut(&mut self) -> impl Iterator<Item = (&str, &mut JsonbValue)>
Returns a mutable iterator over key-value pairs.